//
//  CTEViewController.m
//  ForwardGeocoding
//
//  Created by Andy Riordan on 1/19/12.
//  This is free and unencumbered software released into the public domain.
//
//  Anyone is free to copy, modify, publish, use, compile, sell, or
//  distribute this software, either in source code form or as a compiled
//  binary, for any purpose, commercial or non-commercial, and by any
//  means.
//
//  In jurisdictions that recognize copyright laws, the author or authors
//  of this software dedicate any and all copyright interest in the
//  software to the public domain. We make this dedication for the benefit
//  of the public at large and to the detriment of our heirs and
//  successors. We intend this dedication to be an overt act of
//  relinquishment in perpetuity of all present and future rights to this
//  software under copyright law.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
//  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
//  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//  OTHER DEALINGS IN THE SOFTWARE.
//

#import "CTEViewController.h"

@implementation CTEViewController
@synthesize locationField = _locationField;
@synthesize textView = _textView;
@synthesize activityIndicator = _activityIndicator;
@synthesize geocoder = _geocoder;

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
	
    [self setTitle:@"Forward Geocoding"];
    
    self.geocoder = [[[CLGeocoder alloc] init] autorelease];
}

- (void)dealloc
{
    [_locationField release], _locationField = nil;
    [_textView release], _textView = nil;
    [_activityIndicator release], _activityIndicator = nil;
    [_geocoder release], _geocoder = nil;
    
    [super dealloc];
}

#pragma mark - Delegate methods

- (BOOL)textFieldShouldReturn:(UITextField *)textField
{
    [textField resignFirstResponder];
    [self geolocatePressed:textField];
    
    return YES;
}

#pragma mark - Action methods

- (IBAction)geolocatePressed:(id)sender
{
    CLGeocodeCompletionHandler completionHandler = 
    ^(NSArray *placemarks, NSError *error)
    {
        NSMutableString *results = [[NSMutableString alloc] init];
        
        for (CLPlacemark *placemark in placemarks)
        {
            [results appendFormat:@"%@\n\n", placemark];
        }
        
        if (![results length])
        {
            [results appendString:@"No locations found!"];
        }
        
        [self.textView setText:results];
        [results release], results = nil;
        
        [self.activityIndicator stopAnimating];
    };
    
    [self.activityIndicator startAnimating];
    [self.geocoder geocodeAddressString:self.locationField.text completionHandler:completionHandler];
}

@end
